@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -19,11 +21,15 @@
 """
 Views for managing instance snapshots.
 """
-from django.urls import reverse
-from django.urls import reverse_lazy
+from django.core.urlresolvers import reverse
+from django.core.urlresolvers import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
+from horizon import exceptions
 from horizon import forms
+from horizon.utils import memoized
+
+from openstack_dashboard import api
 
 from openstack_dashboard.dashboards.project.images.snapshots \
     import forms as project_forms
@@ -31,19 +37,24 @@ from openstack_dashboard.dashboards.project.images.snapshots \
 
 class CreateView(forms.ModalFormView):
     form_class = project_forms.CreateSnapshot
-    form_id = "create_snapshot_form"
-    modal_id = "create_snapshot_modal"
-    submit_label = _("Create Snapshot")
-    submit_url = "horizon:project:images:snapshots:create"
     template_name = 'project/images/snapshots/create.html'
     success_url = reverse_lazy("horizon:project:images:index")
-    page_title = _("Create Snapshot")
+
+    @memoized.memoized_method
+    def get_object(self):
+        try:
+            return api.nova.server_get(self.request,
+                self.kwargs["instance_id"])
+        except Exception:
+            redirect = reverse('horizon:project:instances:index')
+            exceptions.handle(self.request,
+                              _("Unable to retrieve instance."),
+                              redirect=redirect)
 
     def get_initial(self):
         return {"instance_id": self.kwargs["instance_id"]}
 
     def get_context_data(self, **kwargs):
         context = super(CreateView, self).get_context_data(**kwargs)
-        args = (self.kwargs['instance_id'],)
-        context['submit_url'] = reverse(self.submit_url, args=args)
+        context['instance'] = self.get_object()
         return context
