@@ -28,7 +28,11 @@ def create_stubbed_exception(cls, status_code=500):
     msg = "Expected failure."
 
     def fake_init_exception(self, code, message, **kwargs):
-        self.code = code
+        if code is not None:
+            if hasattr(self, 'http_status'):
+                self.http_status = code
+            else:
+                self.code = code
         self.message = message
 
     def fake_str(self):
